/* LSAGPILexer.java is a generated file.  You probably want to
 * edit LSAGPILexer.lex to make changes.  Use JFlex to generate it.
 * To generate LSAGPILexer.java
 * Install <a href="http://jflex.de/">JFlex</a> v1.3.2 or later.
 * Once JFlex is in your classpath run<br>
 * <code>java JFlex.Main LSAGPILexer.lex</code><br>
 * You will then have a file called LSAGPILexer.java
 */

/*
 * This file is part of a <a href="http://ostermiller.org/syntax/">syntax
 * highlighting</a> package.
 * Copyright (C) 1999-2002 Stephen Ostermiller
 * http://ostermiller.org/contact.pl?regarding=Syntax+Highlighting
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * See COPYING.TXT for details.
 */

package com.Ostermiller.Syntax.Lexer;

import java.io.*;

/** 
 * LSAGPILexer is a java lexer.  Created with JFlex.  An example of how it is used:
 *  <CODE>
 *  <PRE>
 *  LSAGPILexer shredder = new LSAGPILexer(System.in);
 *  LSAGPIToken t;
 *  while ((t = shredder.getNextToken()) != null){
 *      System.out.println(t);
 *  }
 *  </PRE>
 *  </CODE>
 * The tokens returned should comply with the 
 * <A Href=http://java.sun.com/docs/books/jls/html/>Java 
 * Language Specification</A>.
 * @see LSAGPIToken
 */ 

%%

%public
%class LSAGPILexer
%implements Lexer
%function getNextToken
%type Token 

%{
    private int lastToken;
    private int nextState=YYINITIAL;
    
    /** 
     * next Token method that allows you to control if whitespace and comments are
     * returned as tokens.
     */
    public Token getNextToken(boolean returnComments, boolean returnWhiteSpace)throws IOException{
        Token t = getNextToken();
        while (t != null && ((!returnWhiteSpace && t.isWhiteSpace()) || (!returnComments && t.isComment()))){
            t = getNextToken();
        }
        return (t); 
    }
        
    /**
     * Prints out tokens from a file or System.in.
     * If no arguments are given, System.in will be used for input.
     * If more arguments are given, the first argument will be used as
     * the name of the file to use as input
     *
     * @param args program arguments, of which the first is a filename
     */
    public static void main(String[] args) {
        InputStream in;
        try {
            if (args.length > 0){
                File f = new File(args[0]);
                if (f.exists()){
                    if (f.canRead()){
                        in = new FileInputStream(f);
                    } else {
                        throw new IOException("Could not open " + args[0]);
                    }
                } else {
                    throw new IOException("Could not find " + args[0]);
                }
            } else {
                in = System.in;
            }
            LSAGPILexer shredder = new LSAGPILexer(in);
            Token t;
            while ((t = shredder.getNextToken()) != null) {
                if (t.getID() != LSAGPIToken.WHITE_SPACE){
                    System.out.println(t);
                }
            }
        } catch (IOException e){
            System.out.println(e.getMessage());
        }
    }  

    /**
     * Closes the current input stream, and resets the scanner to read from a new input stream.
	 * All internal variables are reset, the old input stream  cannot be reused
	 * (content of the internal buffer is discarded and lost).
	 * The lexical state is set to the initial state.
     * Subsequent tokens read from the lexer will start with the line, char, and column
     * values given here.
     *
     * @param reader The new input.
     * @param yyline The line number of the first token.
     * @param yychar The position (relative to the start of the stream) of the first token.
     * @param yycolumn The position (relative to the line) of the first token.
     * @throws IOException if an IOExecption occurs while switching readers.
     */
    public void reset(java.io.Reader reader, int yyline, int yychar, int yycolumn) throws IOException{
        yyreset(reader);
        this.yyline = yyline;
		this.yychar = yychar;
		this.yycolumn = yycolumn;
	}
%}

%line
%char
%full

HexDigit=([0-9a-fA-F])
Digit=([0-9])
OctalDigit=([0-7])
TetraDigit=([0-3])
NonZeroDigit=([1-9])
Letter=([a-zA-Z_$])
BLANK=([ ])
TAB=([\t])
FF=([\f])
EscChar=([\\])
CR=([\r])
LF=([\n])
EOL=({CR}|{LF}|{CR}{LF})
WhiteSpace=({BLANK}|{TAB}|{FF}|{EOL})
AnyNonSeparator=([^\t\f\r\n\ \(\)\{\}\[\]\;\,\.\=\>\<\!\~\?\:\+\-\*\/\&\|\^\%\"\'])

OctEscape1=({EscChar}{OctalDigit})
OctEscape2=({EscChar}{OctalDigit}{OctalDigit})
OctEscape3=({EscChar}{TetraDigit}{OctalDigit}{OctalDigit})
OctEscape=({OctEscape1}|{OctEscape2}|{OctEscape3})

UnicodeEscape=({EscChar}[u]{HexDigit}{HexDigit}{HexDigit}{HexDigit})

Escape=({EscChar}([r]|[n]|[b]|[f]|[t]|[\\]|[\']|[\"]))
JavaLetter=({Letter}|{UnicodeEscape})
Identifier=({JavaLetter}({JavaLetter}|{Digit})*)
ErrorIdentifier=({AnyNonSeparator}+)

Comment=("//"[^\r\n]*)
TradCommentBegin=("/*")
DocCommentBegin =("/**")
NonTermStars=([^\*\/]*[\*]+[^\*\/])
TermStars=([\*]+[\/])
CommentText=((([^\*]*[\/])|{NonTermStars})*)
CommentEnd=([^\*]*{TermStars})
TradComment=({TradCommentBegin}{CommentText}{CommentEnd})
DocCommentEnd1=([^\/\*]{CommentText}{CommentEnd})
DocCommentEnd2=({NonTermStars}{CommentText}{CommentEnd})
DocComment=({DocCommentBegin}({DocCommentEnd1}|{DocCommentEnd2}|{TermStars}|[\/]))
OpenComment=({TradCommentBegin}{CommentText}([^\*]*)([\*]*))

Sign=([\+]|[\-])
LongSuffix=([l]|[L])
DecimalNum=(([0]|{NonZeroDigit}{Digit}*))
OctalNum=([0]{OctalDigit}*)
HexNum=([0]([x]|[X]){HexDigit}{HexDigit}*)
DecimalLong=({DecimalNum}{LongSuffix})
OctalLong=({OctalNum}{LongSuffix})
HexLong=({HexNum}{LongSuffix})

SignedInt=({Sign}?{Digit}+)
Expo=([e]|[E])
ExponentPart=({Expo}{SignedInt})
FloatSuffix=([f]|[F])
DoubleSuffix=([d]|[D])
FloatDouble1=({Digit}+[\.]{Digit}*{ExponentPart}?)
FloatDouble2=([\.]{Digit}+{ExponentPart}?)
FloatDouble3=({Digit}+{ExponentPart})
FloatDouble4=({Digit}+)
Double1=({FloatDouble1}{DoubleSuffix}?)
Double2=({FloatDouble2}{DoubleSuffix}?)
Double3=({FloatDouble3}{DoubleSuffix}?)
Double4=({FloatDouble4}{DoubleSuffix})
Float1=({FloatDouble1}{FloatSuffix})
Float2=({FloatDouble2}{FloatSuffix})
Float3=({FloatDouble3}{FloatSuffix})
Float4=({FloatDouble4}{FloatSuffix})
Float=({Float1}|{Float2}|{Float3}|{Float4})
Double=({Double1}|{Double2}|{Double3}|{Double4}) 

ZeroFloatDouble1=([0]+[\.][0]*{ExponentPart}?)
ZeroFloatDouble2=([\.][0]+{ExponentPart}?)
ZeroFloatDouble3=([0]+{ExponentPart})
ZeroFloatDouble4=([0]+)
ZeroDouble1=({ZeroFloatDouble1}{DoubleSuffix}?)
ZeroDouble2=({ZeroFloatDouble2}{DoubleSuffix}?)
ZeroDouble3=({ZeroFloatDouble3}{DoubleSuffix}?)
ZeroDouble4=({ZeroFloatDouble4}{DoubleSuffix})
ZeroFloat1=({ZeroFloatDouble1}{FloatSuffix})
ZeroFloat2=({ZeroFloatDouble2}{FloatSuffix})
ZeroFloat3=({ZeroFloatDouble3}{FloatSuffix})
ZeroFloat4=({ZeroFloatDouble4}{FloatSuffix})
ZeroFloat=({ZeroFloat1}|{ZeroFloat2}|{ZeroFloat3}|{ZeroFloat4})
ZeroDouble=({ZeroDouble1}|{ZeroDouble2}|{ZeroDouble3}|{ZeroDouble4})

ErrorFloat=({Digit}({AnyNonSeparator}|[\.])*)

AnyChrChr=([^\'\n\r\\])
UnclosedCharacter=([\']({Escape}|{OctEscape}|{UnicodeEscape}|{AnyChrChr}))
Character=({UnclosedCharacter}[\'])
MalformedUnclosedCharacter=([\']({AnyChrChr}|({EscChar}[^\n\r]))*)
MalformedCharacter=([\'][\']|{MalformedUnclosedCharacter}[\'])

AnyStrChr=([^\"\n\r\\])
UnclosedString=([\"]({Escape}|{OctEscape}|{UnicodeEscape}|{AnyStrChr})*)
String=({UnclosedString}[\"])
MalformedUnclosedString=([\"]({EscChar}|{AnyStrChr})*)
MalformedString=({MalformedUnclosedString}[\"])

%%

<YYINITIAL> "(" { 
    lastToken = LSAGPIToken.SEPARATOR_LPAREN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
    }
<YYINITIAL> ")" {
    lastToken = LSAGPIToken.SEPARATOR_RPAREN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "{" {
    lastToken = LSAGPIToken.SEPARATOR_LBRACE;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "}" {
    lastToken = LSAGPIToken.SEPARATOR_RBRACE;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "[" {
    lastToken = LSAGPIToken.SEPARATOR_LBRACKET;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "]" {
    lastToken = LSAGPIToken.SEPARATOR_RBRACKET;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> ";" {
    lastToken = LSAGPIToken.SEPARATOR_SEMICOLON;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "," {
    lastToken = LSAGPIToken.SEPARATOR_COMMA;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "." {
    lastToken = LSAGPIToken.SEPARATOR_PERIOD;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}

<YYINITIAL> "=" {
    lastToken = LSAGPIToken.OPERATOR_ASSIGN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> ">" {
    lastToken = LSAGPIToken.OPERATOR_GREATER_THAN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "<" {
    lastToken = LSAGPIToken.OPERATOR_LESS_THAN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "!" {
    lastToken = LSAGPIToken.OPERATOR_LOGICAL_NOT;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "~" {
    lastToken = LSAGPIToken.OPERATOR_BITWISE_COMPLIMENT;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "?" {
    lastToken = LSAGPIToken.OPERATOR_QUESTION;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> ":" {
    lastToken = LSAGPIToken.OPERATOR_COLON;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "+" {
    lastToken = LSAGPIToken.OPERATOR_ADD;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "-" {
    lastToken = LSAGPIToken.OPERATOR_SUBTRACT;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "*" {
    lastToken = LSAGPIToken.OPERATOR_MULTIPLY;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "/" {
    lastToken = LSAGPIToken.OPERATOR_DIVIDE;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "&" {
    lastToken = LSAGPIToken.OPERATOR_BITWISE_AND;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "|" {
    lastToken = LSAGPIToken.OPERATOR_BITWISE_OR;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "^" {
    lastToken = LSAGPIToken.OPERATOR_BITWISE_XOR;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "%" {
    lastToken = LSAGPIToken.OPERATOR_MOD;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}

<YYINITIAL> "==" {
    lastToken = LSAGPIToken.OPERATOR_EQUAL;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "<=" { 
    lastToken = LSAGPIToken.OPERATOR_LESS_THAN_OR_EQUAL;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> ">=" { 
    lastToken = LSAGPIToken.OPERATOR_GREATER_THAN_OR_EQUAL;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "!=" { 
    lastToken = LSAGPIToken.OPERATOR_NOT_EQUAL;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "||" { 
    lastToken = LSAGPIToken.OPERATOR_LOGICAL_OR;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "&&" { 
    lastToken = LSAGPIToken.OPERATOR_LOGICAL_AND;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "++" { 
    lastToken = LSAGPIToken.OPERATOR_INCREMENT;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "--" { 
    lastToken = LSAGPIToken.OPERATOR_DECREMENT;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> ">>" { 
    lastToken = LSAGPIToken.OPERATOR_SHIFT_RIGHT;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "<<" { 
    lastToken = LSAGPIToken.OPERATOR_SHIFT_LEFT;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> ">>>" { 
    lastToken = LSAGPIToken.OPERATOR_SHIFT_RIGHT_UNSIGNED;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "+=" { 
    lastToken = LSAGPIToken.OPERATOR_ADD_ASSIGN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "-=" { 
    lastToken = LSAGPIToken.OPERATOR_SUBTRACT_ASSIGN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "*=" { 
    lastToken = LSAGPIToken.OPERATOR_MULTIPLY_ASSIGN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "/=" { 
    lastToken = LSAGPIToken.OPERATOR_DIVIDE_ASSIGN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "&=" { 
    lastToken = LSAGPIToken.OPERATOR_BITWISE_AND_ASSIGN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "|=" { 
    lastToken = LSAGPIToken.OPERATOR_BITWISE_OR_ASSIGN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "^=" { 
    lastToken = LSAGPIToken.OPERATOR_BITWISE_XOR_ASSIGN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "%=" { 
    lastToken = LSAGPIToken.OPERATOR_MOD_ASSIGN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "<<=" { 
    lastToken = LSAGPIToken.OPERATOR_SHIFT_LEFT_ASSIGN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> ">>=" { 
    lastToken = LSAGPIToken.OPERATOR_SHIFT_RIGHT_ASSIGN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> ">>>=" { 
    lastToken = LSAGPIToken.OPERATOR_SHIFT_RIGHT_UNSIGNED_ASSIGN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
/* Bloques Reservados */
<YYINITIAL> "CUARTO" { 
    lastToken = LSAGPIToken.RESERVED_WORD_CUARTO;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "ELEMENTO" { 
    lastToken = LSAGPIToken.RESERVED_WORD_ELEMENTO;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "ANIMACION" { 
    lastToken = LSAGPIToken.RESERVED_WORD_ANIMACION;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "POSICION" { 
    lastToken = LSAGPIToken.RESERVED_WORD_POSICION;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "ICONO" { 
    lastToken = LSAGPIToken.RESERVED_WORD_ICONO;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "INSTRUCCION" { 
    lastToken = LSAGPIToken.RESERVED_WORD_INSTRUCCION;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "DI" { 
    lastToken = LSAGPIToken.RESERVED_WORD_DI;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "IMAGEN" { 
    lastToken = LSAGPIToken.RESERVED_WORD_IMAGEN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "MASCARA" { 
    lastToken = LSAGPIToken.RESERVED_WORD_MASCARA;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "SONIDOFONDO" { 
    lastToken = LSAGPIToken.RESERVED_WORD_SONIDOFONDO;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "SENTENCIA" { 
    lastToken = LSAGPIToken.RESERVED_WORD_SENTENCIA;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "SALTAR" { 
    lastToken = LSAGPIToken.RESERVED_WORD_SALTAR;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "COLOCAR" { 
    lastToken = LSAGPIToken.RESERVED_WORD_COLOCAR;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "LOCALIZAR" { 
    lastToken = LSAGPIToken.RESERVED_WORD_LOCALIZAR;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "SI" { 
    lastToken = LSAGPIToken.RESERVED_WORD_SI;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "ENTONCES" { 
    lastToken = LSAGPIToken.RESERVED_WORD_ENTONCES;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "COLISION" { 
    lastToken = LSAGPIToken.RESERVED_WORD_COLISION;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "TINTA" { 
    lastToken = LSAGPIToken.RESERVED_WORD_TINTA;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "PAPEL" {
    lastToken = LSAGPIToken.RESERVED_WORD_PAPEL;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "ENTERO" { 
    lastToken = LSAGPIToken.RESERVED_WORD_ENTERO;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "MOVER" { 
    lastToken = LSAGPIToken.RESERVED_WORD_MOVER;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "GIRAR" { 
    lastToken = LSAGPIToken.RESERVED_WORD_GIRAR;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "EQ" { 
    lastToken = LSAGPIToken.RESERVED_WORD_EQ;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "ADD" { 
    lastToken = LSAGPIToken.RESERVED_WORD_ADD;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "DAR" { 
    lastToken = LSAGPIToken.RESERVED_WORD_DAR;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "SONIDO" { 
    lastToken = LSAGPIToken.RESERVED_WORD_SONIDO;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "ACTIVARPANEL" { 
    lastToken = LSAGPIToken.RESERVED_WORD_ACTIVARPANEL;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "LIMPIARPANEL" { 
    lastToken = LSAGPIToken.RESERVED_WORD_LIMPIARPANEL;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "ADDPREGUNTA" { 
    lastToken = LSAGPIToken.RESERVED_WORD_ADDPREGUNTA;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "ESPERARESPUESTA" { 
    lastToken = LSAGPIToken.RESERVED_WORD_ESPERARESPUESTA;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "MIENTRAS" { 
    lastToken = LSAGPIToken.RESERVED_WORD_MIENTRAS;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "SISTEMA" { 
    lastToken = LSAGPIToken.RESERVED_WORD_SISTEMA;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "ANDAR" { 
    lastToken = LSAGPIToken.RESERVED_WORD_ANDAR;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "ETIQUETA" { 
    lastToken = LSAGPIToken.RESERVED_WORD_ETIQUETA;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "TECLA" { 
    lastToken = LSAGPIToken.RESERVED_WORD_TECLA;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "VERBO" {
    lastToken = LSAGPIToken.RESERVED_WORD_VERBO;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "CONMUTATIVO" {
    lastToken = LSAGPIToken.RESERVED_WORD_CONMUTATIVO;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "VERBODEFECTO" { 
    lastToken = LSAGPIToken.RESERVED_WORD_VERBODEFECTO;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "FPS" { 
    lastToken = LSAGPIToken.RESERVED_WORD_FPS;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "ANGULOS" { 
    lastToken = LSAGPIToken.RESERVED_WORD_ANGULOS;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "PANTALLA" { 
    lastToken = LSAGPIToken.RESERVED_WORD_PANTALLA;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "JUGADOR" { 
    lastToken = LSAGPIToken.RESERVED_WORD_JUGADOR;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "INVENTARIO" { 
    lastToken = LSAGPIToken.RESERVED_WORD_INVENTARIO;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "TAMAO" { 
    lastToken = LSAGPIToken.RESERVED_WORD_TAMANO;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "TITULO" { 
    lastToken = LSAGPIToken.RESERVED_WORD_TITULO;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "CURSOR" { 
    lastToken = LSAGPIToken.RESERVED_WORD_CURSOR;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "HABLAR" { 
    lastToken = LSAGPIToken.RESERVED_WORD_HABLAR;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "FUENTE" { 
    lastToken = LSAGPIToken.RESERVED_WORD_FUENTE;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "INICIO" { 
    lastToken = LSAGPIToken.RESERVED_WORD_INICIO;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "SELECCIONARANIMACION" { 
    lastToken = LSAGPIToken.RESERVED_WORD_SELECCIONARANIMACION;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}

<YYINITIAL> "SELECCIONARACTITUD" { 
    lastToken = LSAGPIToken.RESERVED_WORD_SELECCIONARACTITUD;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}

<YYINITIAL> "SELECCIONARJUGADOR" { 
    lastToken = LSAGPIToken.RESERVED_WORD_SELECCIONARJUGADOR;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "PROCEDIMIENTO" { 
    lastToken = LSAGPIToken.RESERVED_WORD_PROCEDIMIENTO;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}



<YYINITIAL> "null" { 
    lastToken = LSAGPIToken.LITERAL_NULL;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}

<YYINITIAL> "true" { 
    lastToken = LSAGPIToken.LITERAL_BOOLEAN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> "false" { 
    lastToken = LSAGPIToken.LITERAL_BOOLEAN;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}

<YYINITIAL> {Identifier} { 
    lastToken = LSAGPIToken.IDENTIFIER;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}

<YYINITIAL> {DecimalNum} {
    /* At this point, the number we found could still be too large.
     * If it is too large, we need to return an error.
     * Java has methods built in that will decode from a string
     * and throw an exception the number is too large 
     */     
    String text = yytext();
    try {
        /* bigger negatives are allowed than positives.  Thus
         * we have to be careful to make sure a neg sign is preserved
         */
        if (lastToken == LSAGPIToken.OPERATOR_SUBTRACT){
            Integer.decode('-' + text);
        } else {
            Integer.decode(text);
        }
        lastToken = LSAGPIToken.LITERAL_INTEGER_DECIMAL;
    } catch (NumberFormatException e){
        lastToken = LSAGPIToken.ERROR_INTEGER_DECIMIAL_SIZE;
    }
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {OctalNum} {
    /* An Octal number cannot be too big.  After removing 
     * initial zeros, It can have 11 digits, the first
     * of which must be 3 or less.
     */
    lastToken = LSAGPIToken.LITERAL_INTEGER_OCTAL;
    int i;     
    String text = yytext();
    int length = text.length();
    for (i=1 ; i<length-11; i++){
        //check for initial zeros
        if (yytext().charAt(i) != '0'){ 
            lastToken = LSAGPIToken.ERROR_INTEGER_OCTAL_SIZE;
        }
    }
    if (length - i > 11){
        lastToken = LSAGPIToken.ERROR_INTEGER_OCTAL_SIZE;
    } else if (length - i == 11){
        // if the rest of the number is as big as possible
        // the first digit can only be 3 or less
        if (text.charAt(i) != '0' && text.charAt(i) != '1' && 
        text.charAt(i) != '2' && text.charAt(i) != '3'){
            lastToken = LSAGPIToken.ERROR_INTEGER_OCTAL_SIZE;
        }
    }
    // Otherwise, it should be OK  
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {HexNum} {
    /* A Hex number cannot be too big.  After removing 
     * initial zeros, It can have 8 digits
     */
    lastToken = LSAGPIToken.LITERAL_INTEGER_HEXIDECIMAL;
    int i;    
    String text = yytext();
    int length = text.length();
    for (i=2 ; i<length-8; i++){
        //check for initial zeros
        if (text.charAt(i) != '0'){ 
            lastToken = LSAGPIToken.ERROR_INTEGER_HEXIDECIMAL_SIZE;
        }
    }
    if (length - i > 8){
        lastToken = LSAGPIToken.ERROR_INTEGER_HEXIDECIMAL_SIZE;
    }
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {DecimalLong} { 
    String text = yytext();
    try {
        if (lastToken == LSAGPIToken.OPERATOR_SUBTRACT){
            Long.decode('-' + text.substring(0,text.length()-1));
        } else {
            Long.decode(text.substring(0,text.length()-1));
        }
        lastToken = LSAGPIToken.LITERAL_LONG_DECIMAL;
    } catch (NumberFormatException e){  
        lastToken = LSAGPIToken.ERROR_LONG_DECIMIAL_SIZE;
    }
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {OctalLong} {
    /* An Octal number cannot be too big.  After removing 
     * initial zeros, It can have 23 digits, the first
     * of which must be 1 or less.  The last will be the L or l
     * at the end.
     */
    lastToken = LSAGPIToken.LITERAL_LONG_OCTAL;
    int i; 
    String text = yytext();
    int length = text.length();
    for (i=1 ; i<length-23; i++){
        //check for initial zeros
        if (text.charAt(i) != '0'){ 
            lastToken = LSAGPIToken.ERROR_LONG_OCTAL_SIZE;
        }
    }
    if (length - i > 23){
        lastToken = LSAGPIToken.ERROR_LONG_OCTAL_SIZE;
    } else if (length - i == 23){
        // if the rest of the number is as big as possible
        // the first digit can only be 3 or less
        if (text.charAt(i) != '0' && text.charAt(i) != '1'){
            lastToken = LSAGPIToken.ERROR_LONG_OCTAL_SIZE;
        }
    }
    // Otherwise, it should be OK  
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {HexLong} {
    /* A Hex long cannot be too big.  After removing 
     * initial zeros, It can have 17 digits, the last of which is
     * the L or l
     */
    lastToken = LSAGPIToken.LITERAL_LONG_HEXIDECIMAL;
    int i;
    String text = yytext();
    int length = text.length();
    for (i=2 ; i<length-17; i++){
        //check for initial zeros
        if (text.charAt(i) != '0'){ 
            lastToken = LSAGPIToken.ERROR_LONG_HEXIDECIMAL_SIZE;
        }
    }
    if (length - i > 17){
        lastToken = LSAGPIToken.ERROR_LONG_HEXIDECIMAL_SIZE;
    }
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {ZeroFloat} {
    /* catch the case of a zero in parsing, so that we do not incorrectly
     * give an error that a number was rounded to zero
     */
    lastToken = LSAGPIToken.LITERAL_FLOATING_POINT;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {ZeroDouble} {
    lastToken = LSAGPIToken.LITERAL_DOUBLE;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {Float} {
    /* Sun s java has a few bugs here.  Their MAX_FLOAT and MIN_FLOAT do not
     * quite match the spec.  Its not far off, so we will deal.  If they fix
     * then we are fixed.  So all good.
     */ 
    Float f;
    try {
        f = Float.valueOf(yytext());
        if (f.isInfinite() || f.compareTo(new Float(0f)) == 0){
            lastToken = LSAGPIToken.ERROR_FLOAT_SIZE;
        } else {
            lastToken = LSAGPIToken.LITERAL_FLOATING_POINT;
        }
    } catch (NumberFormatException e){
        lastToken = LSAGPIToken.ERROR_FLOAT_SIZE;
    }
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {Double} {
    Double d;
    try {
        d = Double.valueOf(yytext());
        if (d.isInfinite() || d.compareTo(new Double(0d)) == 0){
            lastToken = LSAGPIToken.ERROR_DOUBLE_SIZE;
        } else {
            lastToken = LSAGPIToken.LITERAL_DOUBLE;
        }
    } catch (NumberFormatException e){
        lastToken = LSAGPIToken.ERROR_DOUBLE_SIZE;
    } 
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}


<YYINITIAL> {Character} { 
    lastToken = LSAGPIToken.LITERAL_CHARACTER;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {String} { 
    lastToken = LSAGPIToken.LITERAL_STRING;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}

<YYINITIAL> ({WhiteSpace}+) { 
    lastToken = LSAGPIToken.WHITE_SPACE;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}

<YYINITIAL> {Comment} { 
    lastToken = LSAGPIToken.COMMENT_END_OF_LINE;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {DocComment} {
    lastToken = LSAGPIToken.COMMENT_DOCUMENTATION;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {TradComment} {
    lastToken = LSAGPIToken.COMMENT_TRADITIONAL;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}

<YYINITIAL> {UnclosedString} { 
    /* most of these errors have to be caught down near the end of the file.
     * This way, previous expressions of the same length have precedence.
     * This is really useful for catching anything bad by just allowing it 
     * to slip through the cracks. 
     */ 
    lastToken = LSAGPIToken.ERROR_UNCLOSED_STRING;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {MalformedUnclosedString} { 
    lastToken = LSAGPIToken.ERROR_MALFORMED_UNCLOSED_STRING;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {MalformedString} { 
    lastToken = LSAGPIToken.ERROR_MALFORMED_STRING;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {UnclosedCharacter} { 
    lastToken = LSAGPIToken.ERROR_UNCLOSED_CHARACTER;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {MalformedUnclosedCharacter} { 
    lastToken = LSAGPIToken.ERROR_MALFORMED_UNCLOSED_CHARACTER;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {MalformedCharacter} { 
    lastToken = LSAGPIToken.ERROR_MALFORMED_CHARACTER;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {ErrorFloat} { 
    lastToken = LSAGPIToken.ERROR_FLOAT;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {ErrorIdentifier} { 
    lastToken = LSAGPIToken.ERROR_IDENTIFIER;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}
<YYINITIAL> {OpenComment} { 
    lastToken = LSAGPIToken.ERROR_UNCLOSED_COMMENT;
    String text = yytext();
    LSAGPIToken t = (new LSAGPIToken(lastToken,text,yyline,yychar,yychar+text.length(),nextState));
    return (t);
}